import ianywhere.ml.script.*;
import java.sql.*;
import java.util.*;

public class Example {

    public static final int AUTH_USER = 1000;
    public static final int UNAUTH_USER = 4000;

    ServerContext       _serv_context;
    Connection          _log_connection;
    Connection          _sync_connection;

    class MyLogListener implements LogListener {

        public void messageLogged(  ServerContext   sc,
                                    LogMessage      msg )
        {
	    String user;
	    String text;

            try {
                PreparedStatement ps_log = _log_connection.prepareStatement( "insert into mlLog(msgType,msgUser,msgText) values ( ?, ?, ? )" );
		ps_log.setInt    ( 1, msg.getType() );
		user = msg.getUser();
		if( user == null ) {
		    user = "NO USER DEFINED";
		}
		ps_log.setString ( 2, user );
		ps_log.setString ( 3, msg.getText() );
		ps_log.executeUpdate();
		_log_connection.commit();
            } catch( Exception e ) {
                // print some error output to the Mobilink log
                e.printStackTrace();
            }
        }
    }

    public Example( ServerContext sc ) throws SQLException {
        try {
            _serv_context    = sc ;
            _log_connection  = _serv_context.makeConnection();
	    sc.addErrorListener( new MyLogListener() );
	    sc.addWarningListener( new MyLogListener() );
        } catch ( SQLException e ) {
            freeJDBCResources();
            throw e;
        } catch ( Error e ) {
            freeJDBCResources();
            throw e;
        }
    }

    public Example( DBConnectionContext cc ) throws SQLException {
	try {
	    _sync_connection = cc.getConnection();
        } catch ( SQLException e ) {
            freeJDBCResources();
            throw e;
        } catch ( Error e ) {
            freeJDBCResources();
            throw e;
        }
    }

    protected void finalize() throws SQLException, Throwable {
        super.finalize();
        freeJDBCResources();
    }

    private void freeJDBCResources() throws SQLException {
        _serv_context = null;
        _log_connection = null;
    }

    public void endConnection() throws SQLException {
        freeJDBCResources();
    }

    public String handleError( ianywhere.ml.script.InOutInteger actionCode,
                               int errorCode,
	                       String errorMessage,
	                       String user,
	                       String table ) {
        if( errorCode == -196 || errorCode == -194 ) {
	    actionCode.setValue( 1000 );
	} else {
	    actionCode.setValue( 3000 );
	}
	return( null );
    }

}
